#! /bin/csh -f
#############################################################################
# $MAPPER_DIR/MapperEnv.csh: source to setup mapper csh/tsch path,env
#############################################################################
# 09/03/01 -- begin
# ...
# 10/09/06 -- better path order handling
# 11/05/12 -- fix extra colon in {DY}LD_LIBRARY_PATH (now only Linux)
# 13/01/22 -- don't do Darwin version test on Linux
# 13/04/13 -- comment out freetype libpath (now static), fix setuptcl 8.4->8.5!
# 13/08/17 -- if Linux, add local bitmap fonts for new xft-less tk, ->lib/fonts
# 14/02/02 -- ported to sh, include setuptcl here to avoid 2nd source'ing
# 14/09/06 -- Linux add to LD_LIBRARY_PATH for libjpeg62 for run on newer
# 16/03/22 -- MAPPER_LIBRARY_PATH fix allscripts MacOSX 10.11 noenv2subshell
# 18/03/03 -- rm colon from end of single-entry {DY}LD_LIBRARY PATH
# 20/10/02 -- copy/use 75dpi-helvetica X11 fonts (so Linux=Mac)
#TODO: only setenv MAPPER_LIBRARY_PATH (inline pass only)

### report current shell (next works in tcsh or bash, Darwin or Linux)
echo -n "sourcing MapperEnv.csh (csh/tcsh only, not bash!) -- "
echo -n "current shell: "; ps p$$ | grep sh | awk '{print $5}'

### to source this file from anywhere, comment-in/edit next line to install dir
#setenv MAPPER_DIR /usr/local/mapper
### *or* "setenv MAPPER_DIR /your/install/dir" before source'ing

#############################################################################
### catch/prevent execute
if ("$0" == "MapperEnv.csh") then
  echo "MapperEnv.csh: ### source file (exec'ing it has no effect)"
  exit      # not goto skipout because (hopefully) caught exec'd
endif

### warn pre-10.5 MacOSX needs xterm
set rele = `uname -r`
if (`uname` == "Darwin" && $term != "xterm" && $rele:r:r < 9) then
  echo "MapperEnv.csh: ### on MacOSX 10.4: only works from xterm in X11.app"
endif
unset rele

### warn can't find xdpyinfo
if (`which xdpyinfo` !~ *xdpyinfo) then
  echo "MapperEnv.csh: ### xdpyinfo not on path, needed by mapper (in xterm?)"
endif

### if source local, set/reset MAPPER_DIR to here, else use existing if set
if (-e ./MapperEnv.csh) then
  if ($?MAPPER_DIR) then
    echo "MapperEnv.csh: MAPPER_DIR reset to: `pwd`"
  else
    echo "MapperEnv.csh: MAPPER_DIR set to: `pwd`"
  endif
  setenv MAPPER_DIR `pwd`
else   # source'ing from somewhere else, use MAPPER_DIR if exists
  if (! $?MAPPER_DIR) then
    echo "MapperEnv.csh: ### edit 'setenv MAPPER_DIR ...' line to inst dir"
    goto skipout
  else   # MAPPER_DIR set/commented-in above or present in user's env
    echo "MapperEnv.csh: MAPPER_DIR set to: $MAPPER_DIR"
  endif
endif

### find specific architecture
if (! -e $MAPPER_DIR/bin/noarch/getonearch) then
  echo \
    "MapperEnv.csh: ### can't find $MAPPER_DIR/bin/noarch/getonearch (script)"
  goto skipout
endif
set onearch = `$MAPPER_DIR/bin/noarch/getonearch`
if ($onearch == "unknown") then
  echo "MapperEnv.csh: ### don't know this arch:"
  uname -a
  unset onearch
  goto skipout
endif
set sys = `uname -s`

#ORIG commented out
### begin font path addition (if local xserver)
#if (! $?SSH_CLIENT && ! $?SSH_TTY) then
#  if ($sys == "Linux") then  # was check lsb_release, but can be missing!
#    echo \
#      "-----------------------------------------------------------------------"
#    echo "mapper font changes:"
#    set mapperfontdir = $MAPPER_DIR/lib/fonts/ISO8859-2/75dpi
#    echo " xset fp default (reset to default)"  # no bloat
#    xset fp default
#    echo " xset +fp $mapperfontdir"
#    xset +fp $mapperfontdir
#    echo " xset fp rehash"
#    xset fp rehash
#    unset mapperfontdir
#  endif
#  if ($sys == "Darwin") then
#    # default X11 10.4 to 10.8 OK
#  endif
#endif

### begin font path addition (if local xserver)
#set skipfontsflag = 1
if (! $?SSH_CLIENT && ! $?SSH_TTY) then
  set xsetfontmapflag = 0
  if ($sys == "Linux") set xsetfontmapflag = 1
  if ($sys == "Darwin") then
    set darwinrele = `uname -r`
    ## next in case XQuartz stops shipping bitmapped (OK to 2.7.7)
    #if ($darwinrele:r:r > 19) set xsetfontmapflag = 1  # 10.4=8 -> 10.15=19
    unset darwinrele
  endif
  echo "-----------------------------------------------------------------------"
  ### maybe force disable font path addition
  if ($?skipfontsflag) then
    if ($skipfontsflag) then
      unset skipfontsflag
      set xsetfontmapflag = 0
    endif
  endif
  if ($xsetfontmapflag) then  # was chk lsb_release, but Ubuntu missing/broken
    echo "mapper font changes:"
    if ($sys == "Linux") then
      #set mapperfontdir = $MAPPER_DIR/lib/fonts/ISO8859-2/75dpi # Fedora 7
      #set mapperfontdir = $MAPPER_DIR/lib/fonts/bitmap-fonts    # CentOS 5.9
      #set mapperfontdir = $MAPPER_DIR/lib/fonts/75dpi           # MacOSX 10.6
      set mapperfontdir = $MAPPER_DIR/lib/fonts/75dpi-helvetica  # MacOSX 10.6
    endif
    if ($sys == "Darwin") then
      #set mapperfontdir = $MAPPER_DIR/lib/fonts/75dpi           # MacOSX 10.6
      set mapperfontdir = $MAPPER_DIR/lib/fonts/75dpi-helvetica  # MacOSX 10.6
    endif
    echo " xset fp default (reset to default)"  # no bloat
    xset fp default
    echo " xset +fp $mapperfontdir"
    xset +fp $mapperfontdir
    echo " xset fp rehash"
    xset fp rehash
    unset mapperfontdir
  else
    echo "[no X11 fontpath change]"
  endif
  unset xsetfontmapflag
endif

### begin env additions
echo "-----------------------------------------------------------------------"
echo "mapper setenv changes:"
echo " MAPPER_DIR=$MAPPER_DIR"

### for mapper scripts
setenv MAPPERPROG $MAPPER_DIR/bin/$onearch/mapper
echo " MAPPERPROG=$MAPPERPROG"

### maybe add Tcl/Tk/Tix textlibs to setenv (not there if instq)
if (-e $MAPPER_DIR/tcltktix) then
  setenv TCL_LIBRARY   $MAPPER_DIR/tcltktix/lib/noarch/tcl8.5
  echo " TCL_LIBRARY=$TCL_LIBRARY"
  setenv TK_LIBRARY    $MAPPER_DIR/tcltktix/lib/noarch/tk8.5
  echo " TK_LIBRARY=$TK_LIBRARY"
endif

### gather dirs for ${DY}LD_LIBRARY_PATH adjust
# add Tcl/Tk/Tix (omit $MAPPER_DIR/freetype-2.4.4/lib/$onearch since static)
set addldpathlist = ( )
if (-e $MAPPER_DIR/tcltktix) then
  set addldpathlist = ( \
    $MAPPER_DIR/tcltktix/lib/$onearch \
  )
endif
# libjpeg62 for newer OS
if ($sys == "Linux") then
  set addldpathlist = ( \
    $addldpathlist \
    $MAPPER_DIR/lib/$onearch \
  )
endif

### if {DY}LD_LIBRARY_PATH exists, split/save (tr won't work w/dirs w/spaces)
set currldpathlist = ( )
if ($sys == "Darwin") then
  echo " pre-appended to DYLD_LIBRARY_PATH:"
  if ($?DYLD_LIBRARY_PATH) then   # colon-sep to space-sep
    if (`echo $DYLD_LIBRARY_PATH | grep -c " "` == 1) then
      echo "MapperEnv.csh: ### DYLD_LIBRARY_PATH dirs w/spaces  ...quitting"
      goto skipout
    endif
    set currldpathlist = `echo $DYLD_LIBRARY_PATH | tr ':' ' '`
  endif
endif
if ($sys == "Linux") then
  echo " pre-appended to LD_LIBRARY_PATH:"
  if ($?LD_LIBRARY_PATH) then
    if (`echo $LD_LIBRARY_PATH | grep -c " "` == 1) then
      echo "MapperEnv.csh: ### LD_LIBRARY_PATH dirs w/spaces  ...quitting"
      goto skipout
    endif
    set currldpathlist = `echo $LD_LIBRARY_PATH | tr ':' ' '`
  endif
endif
if ($sys == "IRIX" || $sys == "IRIX64") then
  echo " pre-appended to LD_LIBRARYN32_PATH:"
  if ($?LD_LIBRARYN32_PATH) then  # also: LD_LIBRARY_PATH, LD_LIBRARY64_PATH
    if (`echo $LD_LIBRARYN32_PATH | grep -c " "` == 1) then
      echo "MapperEnv.csh: ### LD_LIBRARYN32_PATH dirs w/spaces ...quitting"
      goto skipout
    endif
    set currldpathlist = `echo $LD_LIBRARYN32_PATH | tr ':' ' '`
  endif
endif

### make new colon separated LIBRARY path
set newldpathlist = ""
if ("$currldpathlist" == "") then
  # empty: make new
  set i = 1
  foreach addldpath ( $addldpathlist )
    if ($i == 1) then
      set newldpathlist = "$addldpath"
    else
      set newldpathlist = "${addldpath}:${newldpathlist}"
    endif
    echo "  + $addldpath"
    @ i++
  end
else
  # strip new members already there (maybe behind)
  foreach currldpath ( $currldpathlist )
    foreach addldpath ( $addldpathlist )
      if ($currldpath == $addldpath) goto skipldpath
    end
    if ("$newldpathlist" == "") then
      set newldpathlist = "${currldpath}"
    else
      set newldpathlist = "${newldpathlist}:${currldpath}"
    endif
    skipldpath:
  end
  # add new members to front
  foreach addldpath ( $addldpathlist )
    if ("$newldpathlist" == "") then
      set newldpathlist = "${addldpath}"
    else
      set newldpathlist = "${addldpath}:${newldpathlist}"
    endif
  end
endif
if ($sys == "Darwin") then
  setenv DYLD_LIBRARY_PATH "$newldpathlist"
  setenv MAPPER_LIBRARY_PATH "$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$DYLD_LIBRARY_PATH'
endif
if ($sys == "Linux") then
  setenv LD_LIBRARY_PATH "$newldpathlist"
  setenv MAPPER_LIBRARY_PATH "$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARY_PATH'
endif
if ($sys == "IRIX") then
  setenv LD_LIBRARYN32_PATH "$newldpathlist"
  setenv MAPPER_LIBRARY_PATH "$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARYN32_PATH'
endif
if ($sys == "IRIX64") then
  setenv LD_LIBRARYN32_PATH "$newldpathlist"
  setenv MAPPER_LIBRARY_PATH "$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARYN32_PATH'
endif
unset i currldpath currldpathlist addldpath addldpathlist newldpathlist

### example Darwin error if required shared dylib missing:
#dyld: Library not loaded: /Users/somebody/mapper/
#       libtiff-3.8.2-Darwin-ppc/lib/libtiff.3.dylib
#  Referenced from: /Users/<someuser>/mapper
#  Reason: image not found
#Trace/BPT trap
### example Linux error if required shared dylib missing:
#  mapper: error while loading shared libraries: libfreetype.so.6: cannot
#  open shared object file: No such file or directory

### begin $path additions
echo "-----------------------------------------------------------------------"
echo "pre-appended to csh path:"

### add mapper binary and scripts dirs to beginning of $path
if (-e $MAPPER_DIR/tcltktix) then
  set addpathlist = ( \
    $MAPPER_DIR/tcltktix/bin/$onearch \
    $MAPPER_DIR/bin/$onearch \
    $MAPPER_DIR/bin/noarch \
    $MAPPER_DIR/lib/scripts \
  )  # last ends up most front
else
  set addpathlist = ( \
    $MAPPER_DIR/bin/$onearch \
    $MAPPER_DIR/bin/noarch \
    $MAPPER_DIR/lib/scripts \
  )  # last ends up most front
endif
# strip new members already there (maybe behind)
set currpathlist = ( $path )
set newpathlist = ( )
foreach currpath ( $currpathlist )
  foreach addpath ( $addpathlist )
    if ($currpath == $addpath) goto skippath
  end
  set newpathlist = ( $newpathlist $currpath )  # keep order
  skippath:
end
# add new members to front
foreach addpath ( $addpathlist )
  set newpathlist = ( $addpath $newpathlist)
  echo "  + $addpath"
end
set path = ( $newpathlist )
unset currpath currpathlist addpath addpathlist newpathlist
unset onearch

echo "-----------------------------------------------------------------------"
echo ""

### old setup Xlib tcl if Mac (only csh, now included above)
#if (`uname -s` == "Darwin") then
#  set setuptcl = $MAPPER_DIR/tcltktix/bin/noarch/setuptcl
#  if (-e $setuptcl) source $setuptcl
#endif
#unset setuptcl

############################################################################
### instead of exit since we are source'ing (would exit user's shell!)
skipout:

