#! /bin/sh
#############################################################################
# $MAPPER_DIR/MapperEnv.sh: source to setup mapper sh/bash path,env
#############################################################################
# 09/03/01 -- begin
# ...
# 10/09/06 -- better path order handling
# 11/05/12 -- fix extra colon in {DY}LD_LIBRARY_PATH (now only Linux)
# 13/01/22 -- don't do Darwin version test on Linux
# 13/04/13 -- comment out freetype libpath (now static), fix setuptcl 8.4->8.5!
# 13/08/17 -- if Linux, add local bitmap fonts for new xft-less tk, ->lib/fonts
# 14/02/02 -- port to sh, tcl setup like FreeSurferEnv.sh (avoids source csh)
# 14/09/06 -- Linux add to LD_LIBRARY_PATH for libjpeg62 for run on newer
# 16/03/22 -- MAPPER_LIBRARY_PATH fix allscripts MacOSX 10.11 noenv2subshell
# 18/03/03 -- rm colon from end of single-entry {DY}LD_LIBRARY PATH
# 20/06/02 -- fix PATH parsing to be like FreeSurferEnv.sh (don't bork zsh)
# 20/06/08 -- rm empty path entry every new source
# 20/10/02 -- copy/use 75dpi-helvetica X11 fonts (so Linux=Mac)
# TODO: fix mapper.c: opts for system profiler changed

#############################################################################
### standard use of this script:
#cd ~/mapper     # or to wherever you installed mapper
#source MapperEnv.sh

### to source this file from anywhere, comment-in/edit next line to install dir
#export MAPPER_DIR=/your/install/dir/mapper
### *or* "export MAPPER_DIR=/your/install/dir/mapper"  # before source from any

#############################################################################
### report current shell (next works tcsh/bash, Darwin/Linux/IRIX)
echo ""
echo -n "MapperEnv.sh (vers=10) requires sh/bash/zsh -- current shell: "
myshell=`ps -p$$ | grep sh | awk '{print $4}'`
echo $myshell
echo ""
## check if zsh (for $PATH parsing)
foundzsh=0
if [ "$myshell" = "zsh" ]; then
  foundzsh=1;
  echo "MapperEnv.sh: zsh detected (OK)"
fi
## bashrc fails b/c Mac doesn't pass $path, would have to guess abs ps/grep/awk
#foundzsh=0
## 1st: system source, 2nd: new xterm, 3rd: re-source in shell
#if [ "$0" = "-zsh" ] || [ "$0" = "zsh" ] || \
#   [ "$0" = "/Users/sereno/.zshrc" ]; then
#  foundzsh=1
#fi

### prevent execute
## N.B.: still broken: this prevents source inside script since $0=scriptname
#if [ $0 != "bash" ] && [ $0 != "sh" ] && [ $0 != "-bash" ] && \
#   [ $0 != "-sh" ]; then
#  echo "MapperEnv.sh: ### source file (exec'ing it has no effect on env)"
#  echo ""
#  echo "use: source MapperEnv.sh"
#  echo ""
#  exit      # not return because (hopefully) was exec'd
#fi

### warn pre-10.5 MacOSX needs xterm
if [ `uname` = "Darwin" ]; then
  rele=`uname -r`
  needxterm=0
  case "$rele" in 8.*.*) needxterm=1 ;; esac
  if [ $TERM != "xterm" ] && [ $needxterm = 1 ]; then
    echo "MapperEnv.sh: ### on MacOSX 10.4: only works from xterm in X11.app"
  fi
fi
unset rele needxterm

### warn can't find xdpyinfo
if [ "`which xdpyinfo`" = "xdpyinfo: Command not found." ] || \
   [ "`which xdpyinfo`" = "xdpyinfo not found" ]; then
  echo "MapperEnv.sh: ### needed X11 utility xdpyinfo not on path"
  if [ `uname` = "Darwin" ]; then
    echo \
"MapperEnv.sh: ### put /opt/X11/bin/xdpyinfo on \$PATH or run mapper from xterm"
  fi
  return     # we are sourcing: don't exit current shell
fi

### if source local, set/reset MAPPER_DIR to here, else use existing if set
if [ -e ./MapperEnv.sh ]; then
  if [ -z "$MAPPER_DIR" ]; then
    echo "MapperEnv.sh: MAPPER_DIR set to: `pwd`"
  else
    echo "MapperEnv.sh: MAPPER_DIR reset to: `pwd`"
  fi
  export MAPPER_DIR=`pwd`
else   # source'ing from somewhere else, use MAPPER_DIR if exists
  if [ -z "$MAPPER_DIR" ]; then
    echo "MapperEnv.sh: ### edit 'export MAPPER_DIR=...' line to inst dir"
    return    # we are sourcing: don't exit current shell
  else   # MAPPER_DIR set/commented-in above or present in user's env
    echo "MapperEnv.sh: MAPPER_DIR set to: $MAPPER_DIR"
  fi
fi

### find specific architecture
if [ ! -e $MAPPER_DIR/bin/noarch/getonearch ]; then
  echo "MapperEnv.sh: ### can't find $MAPPER_DIR/bin/noarch/getonearch (script)"
  return
fi
onearch=`$MAPPER_DIR/bin/noarch/getonearch`
if [ $onearch = "unknown" ]; then
  echo "MapperEnv.sh: ### don't know this arch:"
  uname -a
  unset onearch
  return
fi
sys=`uname -s`

#ORIG commented out
### begin font path addition (if local xserver)
#if [ -z $SSH_CLIENT ] && [ -z $SSH_TTY ]; then
#  if [ $sys = "Linux" ]; then  # was check lsb_release, but unreliable Ubuntu
#    echo \
#      "-----------------------------------------------------------------------"
#    echo "mapper font changes:"
#    mapperfontdir=$MAPPER_DIR/lib/fonts/ISO8859-2/75dpi
#    echo " xset fp default (reset to default)"  # no bloat
#    xset fp default
#    echo " xset +fp $mapperfontdir"
#    xset +fp $mapperfontdir
#    echo " xset fp rehash"
#    xset fp rehash
#    unset mapperfontdir
#  fi
#  if [ $sys = "Darwin" ]; then
#    echo "[no X font change for Darwin]"
#  fi
#fi

### begin font path addition (if local xserver)
#skipfontsflag=1   # uncomment to force off for all arch
if [ -z "$SSH_CLIENT" ] && [ -z "$SSH_TTY" ]; then
  xsetfontmapflag=0
  if [ $sys = "Linux" ]; then xsetfontmapflag=1; fi
  if [ $sys = "Darwin" ]; then   # default X11 10.4 to 10.15 OK
    darwinrele=`uname -r`
    xsetfontmapflag=0
    ## next in case XQuartz stops shipping fonts (up to XQuartz 2.7.7 OK)
    #xsetfontmapflag=1
    #case $darwinrele in 8.*.*) xsetfontmapflag=0 ;; esac   # 10.4
    #case $darwinrele in 9.*.*) xsetfontmapflag=0 ;; esac   # 10.5
    #case $darwinrele in 10.*.*) xsetfontmapflag=0 ;; esac  # 10.6
    #case $darwinrele in 11.*.*) xsetfontmapflag=0 ;; esac  # 10.7
    #case $darwinrele in 12.*.*) xsetfontmapflag=0 ;; esac  # 10.8
    #case $darwinrele in 13.*.*) xsetfontmapflag=0 ;; esac  # 10.9
    #case $darwinrele in 14.*.*) xsetfontmapflag=0 ;; esac  # 10.10
    #case $darwinrele in 15.*.*) xsetfontmapflag=0 ;; esac  # 10.11
    #case $darwinrele in 16.*.*) xsetfontmapflag=0 ;; esac  # 10.12
    #case $darwinrele in 17.*.*) xsetfontmapflag=0 ;; esac  # 10.13
    #case $darwinrele in 18.*.*) xsetfontmapflag=0 ;; esac  # 10.14
    #case $darwinrele in 19.*.*) xsetfontmapflag=0 ;; esac  # 10.15
    unset darwinrele
  fi
 echo "-----------------------------------------------------------------------"
  ### maybe force disable font path addition
  if [ ! -z "$skipfontsflag" ]; then
    if [ $skipfontsflag = 1 ]; then
      unset skipfontsflag
      xsetfontmapflag=0
    fi
  fi
  if [ $xsetfontmapflag -eq 1 ]; then #was chk lsb_release, unreliable on Ubuntu
    echo "mapper font changes:"
    if [ $sys = "Linux" ]; then
      #mapperfontdir=$MAPPER_DIR/lib/fonts/ISO8859-2/75dpi # Fedora 7
      #mapperfontdir=$MAPPER_DIR/lib/fonts/bitmap-fonts    # CentOS 5.9
      #mapperfontdir=$MAPPER_DIR/lib/fonts/75dpi           # MacOSX 10.6 all
      mapperfontdir=$MAPPER_DIR/lib/fonts/75dpi-helvetica  # MacOSX 10.6 helv
    fi
    if [ $sys = "Darwin" ]; then
      #mapperfontdir=$MAPPER_DIR/lib/fonts/75dpi           # MacOSX 10.6 all
      mapperfontdir=$MAPPER_DIR/lib/fonts/75dpi-helvetica  # MacOSX 10.6 helv
    fi
    echo " xset fp default (reset to default)"  # no bloat re-run
    xset fp default
    echo " xset +fp $mapperfontdir"
    xset +fp $mapperfontdir
    echo " xset fp rehash"
    xset fp rehash
    unset mapperfontdir
  else
    echo "[no X11 fontpath change]"
  fi
fi

### begin env additions
echo "-----------------------------------------------------------------------"
echo "mapper env changes:"
echo " MAPPER_DIR=$MAPPER_DIR"

### for mapper scripts
export MAPPERPROG=$MAPPER_DIR/bin/$onearch/mapper
echo " MAPPERPROG=$MAPPERPROG"

### add Tcl/Tk/Tix textlibs to env
export TCL_LIBRARY=$MAPPER_DIR/tcltktix/lib/noarch/tcl8.5
echo " TCL_LIBRARY=$TCL_LIBRARY"
export TK_LIBRARY=$MAPPER_DIR/tcltktix/lib/noarch/tk8.5
echo " TK_LIBRARY=$TK_LIBRARY"

### gather dirs for ${DY}LD_LIBRARY_PATH adjust
# add Tcl/Tk/Tix (omit $MAPPER_DIR/freetype-2.4.4/lib/$onearch since static)
addldpathlist="$MAPPER_DIR/tcltktix/lib/$onearch"
# libjpeg62 for newer OS
if [ $sys = "Linux" ]; then
  addldpathlist="$addldpathlist:$MAPPER_DIR/lib/$onearch"
fi

### check if {DY}LD_LIBRARY_PATH exists
currldpathlist=""
if [ $sys = "Darwin" ]; then
  echo " pre-appended to DYLD_LIBRARY_PATH (+ cp to MAPPER_LIBRARY_PATH):"
  if [ ! -z "$DYLD_LIBRARY_PATH" ]; then
    currldpathlist=$DYLD_LIBRARY_PATH
  fi
fi
if [ $sys = "Linux" ]; then
  echo " pre-appended to LD_LIBRARY_PATH:"
  if [ ! -z "$LD_LIBRARY_PATH" ]; then
    currldpathlist=$LD_LIBRARY_PATH
  fi
fi
if [ $sys = "IRIX" ] || [ $sys = "IRIX64" ]; then
  echo " pre-appended to LD_LIBRARYN32_PATH:"
  if [ ! -z "$LD_LIBRARYN32_PATH" ]; then
    #currldpathlist=$LD_LIBRARYN_PATH
    currldpathlist=$LD_LIBRARYN32_PATH
    #currldpathlist=$LD_LIBRARYN64_PATH
  fi
fi

### so zsh can run sh 'for' code for ldpath, path add (else only 1 'for' loop)
if [ $foundzsh -eq 1 ]; then
  set -o SH_WORD_SPLIT
fi

### make new colon separated LIBRARY path, allow path spaces
saveifs=$IFS
IFS=':'
newldpathlist=""
if [ "$currldpathlist" = "" ]; then
  # empty: make new
  i=1
  for addldpath in $addldpathlist; do
    if [ $i = 1 ]; then
      newldpathlist="$addldpath"
    else
      newldpathlist="${addldpath}:${newldpathlist}"
    fi
    echo "  + $addldpath"
    i=`expr $i + 1`
  done
else
  # strip new members already there (maybe behind) (no goto)
  for currldpath in $currldpathlist; do
    found=0
    for addldpath in $addldpathlist; do
      if [ $currldpath = $addldpath ]; then found=1; fi
    done
    if [ $found = 0 ]; then
      if [ "$newldpathlist" = "" ]; then
        newldpathlist="${currldpath}"
      else
        newldpathlist="${newldpathlist}:${currldpath}"
      fi
    fi
  done
  # add new members to front
  for addldpath in $addldpathlist; do
    if [ "$newldpathlist" = "" ]; then
      newldpathlist="${addldpath}"
    else
      newldpathlist="${addldpath}:${newldpathlist}"
    fi
    echo "  + $addldpath"
  done
fi
if [ $sys = "Darwin" ]; then
  export DYLD_LIBRARY_PATH="$newldpathlist"
  export MAPPER_LIBRARY_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$DYLD_LIBRARY_PATH'
fi
if [ $sys = "Linux" ]; then
  export LD_LIBRARY_PATH="$newldpathlist"
  export MAPPER_LIBRARY_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARY_PATH'
fi
if [ $sys = "IRIX" ]; then
  export LD_LIBRARYN32_PATH="$newldpathlist"
  export MAPPER_LIBRARYN32_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARYN32_PATH'
fi
if [ $sys = "IRIX64" ]; then
  export LD_LIBRARYN32_PATH="$newldpathlist"
  export MAPPER_LIBRARYN32_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARYN32_PATH'
fi
# cleanup
IFS=$saveifs
unset i currldpath currldpathlist addldpath addldpathlist newldpathlist saveifs

### begin $PATH additions
echo "-----------------------------------------------------------------------"
echo "pre-appended to sh \$PATH:"

### add mapper binary and scripts dirs to beginning of $path
saveifs=$IFS
IFS=':'
addpathlist="\
$MAPPER_DIR/tcltktix/bin/$onearch:\
$MAPPER_DIR/bin/$onearch:\
$MAPPER_DIR/bin/noarch:\
$MAPPER_DIR/lib/scripts\
"  # last ends up most front

### strip new members already there (maybe behind), keep order
currpathlist=$PATH
newpathlist=""
for currpath in $currpathlist; do
  found=0
  for addpath in $addpathlist; do
    if [ "$currpath" = "$addpath" ]; then found=1; fi
  done
  if [ $found = 0 ]; then
    if [ "$newpathlist" = "" ]; then
      newpathlist="${currpath}"
    else
      newpathlist="${newpathlist}:${currpath}"
    fi
  fi
done

### add new members to front
for addpath in $addpathlist; do
  newpathlist="${addpath}:${newpathlist}"
  echo "  + $addpath"
done
export PATH="$newpathlist"
# cleanup
IFS=$saveifs
unset currpath currpathlist addpath addpathlist newpathlist saveifs
unset onearch

echo "-----------------------------------------------------------------------"
echo ""

### cleanup: go back to default zsh list behavior since we are source'ing
if [ $foundzsh -eq 1 ]; then
  set +o SH_WORD_SPLIT  # should check init state...
fi
unset myshell foundzsh

### old setup Xlib tcl if Mac (only csh, now ported/included above)
#if [ $sys = "Darwin" ]; then
#  setuptcl=$MAPPER_DIR/tcltktix/bin/noarch/setuptcl.sh
#  if [ -e $setuptcl ]; then source $setuptcl; fi
#fi
#unset setuptcl

